==> qtjambi-quick-debuginfo-macos-6.5.3.jar: sources/QtJambiQuick/QQuickItem_shell.h <==
#ifndef QQUICKITEM_SHELL_H
#define QQUICKITEM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQuick/qquickitem.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qtransform.h>
#include <QtJambi/JavaAPI>
#include <QtJambiQml/hashes.h>
#include <QtQml/qjsvalue.h>
#include <QtQuick/qquickitemgrabresult.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgnode.h>
#include <QtQuick/qsgtextureprovider.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QQuickItem_shell : public QQuickItem, public QtJambiShellInterface
{
public:
    QQuickItem_shell(QQuickItem* parent0 = nullptr);
    ~QQuickItem_shell() override;

    QRectF boundingRect() const override;
    void childEvent(QChildEvent* event0) override;
    bool childMouseEventFilter(QQuickItem* arg__1, QEvent* arg__2) override;
    void classBegin() override;
    QRectF clipRect() const override;
    void componentComplete() override;
    void connectNotify(const QMetaMethod& signal0) override;
    bool contains(const QPointF& point0) const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* arg__1) override;
    void dragLeaveEvent(QDragLeaveEvent* arg__1) override;
    void dragMoveEvent(QDragMoveEvent* arg__1) override;
    void dropEvent(QDropEvent* arg__1) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* arg__1) override;
    void focusOutEvent(QFocusEvent* arg__1) override;
    void geometryChange(const QRectF& newGeometry0, const QRectF& oldGeometry1) override;
    void hoverEnterEvent(QHoverEvent* event0) override;
    void hoverLeaveEvent(QHoverEvent* event0) override;
    void hoverMoveEvent(QHoverEvent* event0) override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isTextureProvider() const override;
    void itemChange(QQuickItem::ItemChange arg__1, const QQuickItem::ItemChangeData& arg__2) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void mouseUngrabEvent() override;
    void releaseResources() override;
    QSGTextureProvider* textureProvider() const override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* event0) override;
    void touchUngrabEvent() override;
    QSGNode* updatePaintNode(QSGNode* arg__1, QQuickItem::UpdatePaintNodeData* arg__2) override;
    void updatePolish() override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickItem_access : public QQuickItem
{
    jboolean __qt_heightValid(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isComponentComplete(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setImplicitSize_qreal_qreal(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble arg__1, jdouble arg__2);
    void __qt_updateInputMethod_Qt_InputMethodQueries(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint queries0);
    jboolean __qt_widthValid(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_boundingRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_childMouseEventFilter_QQuickItem_ptr_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1, QtJambiNativeID arg__2);
    void __qt_classBegin(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_clipRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_componentComplete(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_contains_cref_QPointF_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID point0) const;
    void __qt_dragEnterEvent_QDragEnterEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_dragLeaveEvent_QDragLeaveEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_dragMoveEvent_QDragMoveEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_dropEvent_QDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_focusInEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_geometryChange_cref_QRectF_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID newGeometry0, QtJambiNativeID oldGeometry1);
    void __qt_hoverEnterEvent_QHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverLeaveEvent_QHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverMoveEvent_QHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_inputMethodEvent_QInputMethodEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_inputMethodQuery_Qt_InputMethodQuery_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint query0) const;
    jboolean __qt_isTextureProvider(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_itemChange_QQuickItem_ItemChange_cref_QQuickItem_ItemChangeData(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1, jobject arg__2);
    void __qt_keyPressEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_keyReleaseEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseDoubleClickEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseMoveEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mousePressEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseReleaseEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseUngrabEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_releaseResources(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_textureProvider(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_touchEvent_QTouchEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_touchUngrabEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_updatePaintNode_QSGNode_ptr_QQuickItem_UpdatePaintNodeData_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1, QtJambiNativeID arg__2);
    void __qt_updatePolish(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_wheelEvent_QWheelEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
};

#endif // QQUICKITEM_SHELL_H

==> qtjambi-quick-debuginfo-macos-6.5.6.jar: sources/QtJambiQuick/QQuickItem_shell.h <==
#ifndef QQUICKITEM_SHELL_H
#define QQUICKITEM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qquickitem.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qtransform.h>
#include <QtJambi/JavaAPI>
#include <QtJambiQml/hashes.h>
#include <QtQml/qjsvalue.h>
#include <QtQuick/qquickitemgrabresult.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgnode.h>
#include <QtQuick/qsgtextureprovider.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QQuickItem_shell : public QQuickItem, public QtJambiShellInterface
{
public:
    QQuickItem_shell(QQuickItem* parent0 = nullptr);
    ~QQuickItem_shell() override;

    QRectF boundingRect() const override;
    void childEvent(QChildEvent* event0) override;
    bool childMouseEventFilter(QQuickItem* arg__1, QEvent* arg__2) override;
    void classBegin() override;
    QRectF clipRect() const override;
    void componentComplete() override;
    void connectNotify(const QMetaMethod& signal0) override;
    bool contains(const QPointF& point0) const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* arg__1) override;
    void dragLeaveEvent(QDragLeaveEvent* arg__1) override;
    void dragMoveEvent(QDragMoveEvent* arg__1) override;
    void dropEvent(QDropEvent* arg__1) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* arg__1) override;
    void focusOutEvent(QFocusEvent* arg__1) override;
    void geometryChange(const QRectF& newGeometry0, const QRectF& oldGeometry1) override;
    void hoverEnterEvent(QHoverEvent* event0) override;
    void hoverLeaveEvent(QHoverEvent* event0) override;
    void hoverMoveEvent(QHoverEvent* event0) override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isTextureProvider() const override;
    void itemChange(QQuickItem::ItemChange arg__1, const QQuickItem::ItemChangeData& arg__2) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void mouseUngrabEvent() override;
    void releaseResources() override;
    QSGTextureProvider* textureProvider() const override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* event0) override;
    void touchUngrabEvent() override;
    QSGNode* updatePaintNode(QSGNode* arg__1, QQuickItem::UpdatePaintNodeData* arg__2) override;
    void updatePolish() override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickItem_access : public QQuickItem
{
    jboolean __qt_heightValid_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isComponentComplete_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setImplicitSize_qreal_qreal(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble arg__1, jdouble arg__2);
    void __qt_updateInputMethod_Qt_InputMethodQueries(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint queries0);
    jboolean __qt_widthValid_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_boundingRect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_childMouseEventFilter_QQuickItem_ptr_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1, QtJambiNativeID arg__2);
    void __qt_classBegin(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_clipRect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_componentComplete(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_contains_cref_QPointF_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID point0) const;
    void __qt_dragEnterEvent_QDragEnterEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_dragLeaveEvent_QDragLeaveEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_dragMoveEvent_QDragMoveEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_dropEvent_QDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_focusInEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_geometryChange_cref_QRectF_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID newGeometry0, QtJambiNativeID oldGeometry1);
    void __qt_hoverEnterEvent_QHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverLeaveEvent_QHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverMoveEvent_QHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_inputMethodEvent_QInputMethodEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_inputMethodQuery_Qt_InputMethodQuery_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint query0) const;
    jboolean __qt_isTextureProvider_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_itemChange_QQuickItem_ItemChange_cref_QQuickItem_ItemChangeData(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1, jobject arg__2);
    void __qt_keyPressEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_keyReleaseEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseDoubleClickEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseMoveEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mousePressEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseReleaseEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseUngrabEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_releaseResources(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_textureProvider_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_touchEvent_QTouchEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_touchUngrabEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_updatePaintNode_QSGNode_ptr_QQuickItem_UpdatePaintNodeData_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1, QtJambiNativeID arg__2);
    void __qt_updatePolish(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_wheelEvent_QWheelEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
};

#endif // QQUICKITEM_SHELL_H
